# hpsim
A (hopefully) high performance, modular simulator for everything from molecules to galaxy clusters.

v0.0.1:
Trying to setup the package. Internally I'm at 0.3.2 - I hope to have the package reach the same point soon.

v0.0.2 - 0.0.11:
Trying to make the package actually work as it did when it was only one file locally.
I had yet to discover local developer mode.

v0.3.2:
Got the package to function. It was a good day.

v0.3.3:
Messed up all the files and updating the version # was the way forward.
This procedure will seem embarrassing in five years.
